@@ -1,6 +1,12 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
-set -e -o pipefail
+. $(dirname "${BASH_SOURCE[0]}")/common.sh
+
+# gdc 4.8.5 not working with ddox due to missing
+# std.experimental.allocator.mallocator for libdparse
+if [ ${DC} = gdc ]; then
+    exit 0
+fi
 
 (cd $CURR_DIR/ddox/default && $DUB build -b ddox)
 grep -qF ddox_project $CURR_DIR/ddox/default/docs/index.html
