@@ -3,7 +3,7 @@ DIR=$(dirname "${BASH_SOURCE[0]}")
 
 . "$DIR"/common.sh
 
-PORT=$(($$ + 1024)) # PID + 1024
+PORT=$(getRandomPort)
 tempDir="issue1574-addcommand"
 
 "$DUB" build --single "$DIR"/test_registry.d
